import pandas as pd
import tldextract

def clean_columns(df: pd.DataFrame) -> pd.DataFrame:
    df.columns = [col.lower().replace(" ", "_").replace(".", "") for col in df.columns]
    return df


def clean_domain(url: str) -> str:    
    ext = tldextract.extract(url.strip()) # handled uk.co, and high stars
    return ext.registered_domain

def domain_is_none(url: str) -> bool:
    return url is None or url == ""



from dotenv import load_dotenv

load_dotenv()

from gandai import (constants, google, gpt, grata, helpers, models, query,
                    secrets)
from gandai.db import connect_with_connector
from gandai.tasks import trigger_process_event

__all__ = [
    "query",
    "gpt",
    "google",
    "grata",
    "secrets",
    "constants",
    "models",
    "helpers",
    "connect_with_connector",
    "trigger_process_event",
]
